==> jc-1.4.0.tar.gz: javax/security/auth/login/Configuration__241.c <==
// final class javax.security.auth.login.Configuration$1

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d38282f3d5f80887 java_lang_SecurityManager
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 94d357637b968dda java_lang_StringBuffer
// @dep_class a0a8fafccf4b2db9 java_lang_System
// @dep_class fe58a8cfe9b5b994 java_security_PrivilegedAction
// @dep_class e2c68366fdd2883d java_security_Security
// @dep_class 884c3edb343dfb63 java_util_Properties
// @dep_class 8290523a8a34bfb5 javax_security_auth_login_Configuration__241

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_SecurityManager
// @dep_header java_lang_String
// @dep_header java_lang_StringBuffer
// @dep_header java_lang_System
// @dep_header java_security_PrivilegedAction
// @dep_header java_security_Security
// @dep_header java_util_Properties
// @dep_header javax_security_auth_login_Configuration__241

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/SecurityManager.h"
#include "java/lang/String.h"
#include "java/lang/StringBuffer.h"
#include "java/lang/System.h"
#include "java/security/PrivilegedAction.h"
#include "java/security/Security.h"
#include "java/util/Properties.h"
#include "javax/security/auth/login/Configuration__241.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_javax_security_auth_login_Configuration__241$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_javax_security_auth_login_Configuration__241$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_security_auth_login_Configuration__241$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_javax_security_auth_login_Configuration__241$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_security_auth_login_Configuration__241$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_javax_security_auth_login_Configuration__241$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_security_auth_login_Configuration__241$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_security_auth_login_Configuration__241, _init$52f4ad9f2989aeee);

void
_jc_javax_security_auth_login_Configuration__241$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_javax_security_auth_login_Configuration__241$object *this)
{
	struct _jc_javax_security_auth_login_Configuration__241$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(74);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public final java.lang.Object run()
//

static _jc_linenum _jc_javax_security_auth_login_Configuration__241$linenum_table$run$b190d7b16d5785b8[];

static const unsigned char _jc_javax_security_auth_login_Configuration__241$param_ptypes$run$b190d7b16d5785b8[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_security_auth_login_Configuration__241$method_info$run$b190d7b16d5785b8 = {
	.name=			"run",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_javax_security_auth_login_Configuration__241$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_javax_security_auth_login_Configuration__241$param_ptypes$run$b190d7b16d5785b8,
	.signature_hash=	_JC_JLONG(0xb190d7b16d5785b8),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_javax_security_auth_login_Configuration__241$method$run$b190d7b16d5785b8,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_security_auth_login_Configuration__241$vtable, javax_security_auth_login_Configuration__241.run$b190d7b16d5785b8) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_security_auth_login_Configuration__241$linenum_table$run$b190d7b16d5785b8
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_security_auth_login_Configuration__241, run$b190d7b16d5785b8);

_jc_java_lang_Object$object *
_jc_javax_security_auth_login_Configuration__241$method$run$b190d7b16d5785b8(_jc_env *const env, _jc_javax_security_auth_login_Configuration__241$object *this)
{
	jint i0;
	struct _jc_javax_security_auth_login_Configuration__241$object *r0;
	struct _jc_java_lang_String$object *r1;
	struct _jc_java_lang_StringBuffer$object *r2;
	struct _jc_java_lang_String$object *r3;
	struct _jc_java_util_Properties$object *r4;
	struct _jc_java_lang_SecurityManager$object *r5;
	struct _jc_java_lang_String$object *r6;
	struct _jc_java_lang_String$object *r7;
	_jc_char_array *r8;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_ACTIVE_USE(env, java_security_Security);
	_JC_LINE_NUMBER(77);				// 0
	r1 = _JC_STRING(env, "login.configuration.provider");
	_JC_ACTIVE_USE(env, java_lang_System);
	r5 = _JC_STATIC_FIELD(env, java_lang_SecurityManager, current, 0);
	if (r5 == _JC_NULL)
		goto label0;
	r2 = _JC_NEW(env, java_lang_StringBuffer);
	r7 = _JC_STRING(env, "getProperty.");
	i0 = _JC_PRIM_FIELD(env, r7, java_lang_String, count);
	_JC_PRIM_FIELD(env, r2, java_lang_StringBuffer, count) = i0;
	i0 = _JC_PRIM_FIELD(env, r2, java_lang_StringBuffer, count);
	i0 = i0 + 16;
	r8 = _JC_NEW_PRIM_ARRAY(env, char, 1, i0);
	_JC_REF_FIELD(env, r2, java_lang_StringBuffer, value) = r8;
	i0 = _JC_PRIM_FIELD(env, r2, java_lang_StringBuffer, count);
	r8 = _JC_REF_FIELD(env, r2, java_lang_StringBuffer, value);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_String, getChars$c684dea7317ff063, 0, r7, 0, i0, r8, 0);
	r2 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r2, r1);
	r6 = _JC_NEW(env, java_lang_String);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_String, _init$aa54f0755ac8f3ce, 0, r6, r2);
	_JC_INVOKE_VIRTUAL(env, java_lang_SecurityManager, checkSecurityAccess$3e1898ffed69827d, r5, r6);

label0:
	r4 = _JC_STATIC_FIELD(env, java_security_Security, secprops, 1);
	r3 = _JC_INVOKE_VIRTUAL(env, java_util_Properties, getProperty$17fb18205ea95f87, r4, r1);
	return r3;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_security_auth_login_Configuration__241$methods[] = {
	&_jc_javax_security_auth_login_Configuration__241$method_info$_init$52f4ad9f2989aeee,
	&_jc_javax_security_auth_login_Configuration__241$method_info$run$b190d7b16d5785b8
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_javax_security_auth_login_Configuration__241$interfaces[] = {
	&_jc_java_security_PrivilegedAction$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_javax_security_auth_login_Configuration__241$imethod_hash_bucket_56[] = {
	&_jc_javax_security_auth_login_Configuration__241$method_info$run$b190d7b16d5785b8,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_javax_security_auth_login_Configuration__241$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[56]=	_jc_javax_security_auth_login_Configuration__241$imethod_hash_bucket_56
};

// Interface "quick" lookup hash table
static const void *_jc_javax_security_auth_login_Configuration__241$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[56]=	&_jc_javax_security_auth_login_Configuration__241$method$run$b190d7b16d5785b8
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_security_auth_login_Configuration__241$instanceof_hash_bucket_20[] = {
	&_jc_java_security_PrivilegedAction$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_security_auth_login_Configuration__241$instanceof_hash_bucket_53[] = {
	&_jc_javax_security_auth_login_Configuration__241$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_security_auth_login_Configuration__241$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_security_auth_login_Configuration__241$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[20]=	_jc_javax_security_auth_login_Configuration__241$instanceof_hash_bucket_20,
	[53]=	_jc_javax_security_auth_login_Configuration__241$instanceof_hash_bucket_53,
	[113]=	_jc_javax_security_auth_login_Configuration__241$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_security_auth_login_Configuration__241$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/SecurityManager",	_JC_JLONG(0xd38282f3d5f80887) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/lang/StringBuffer",	_JC_JLONG(0x94d357637b968dda) },
	{ "java/lang/System",	_JC_JLONG(0xa0a8fafccf4b2db9) },
	{ "java/security/PrivilegedAction",	_JC_JLONG(0xfe58a8cfe9b5b994) },
	{ "java/security/Security",	_JC_JLONG(0xe2c68366fdd2883d) },
	{ "java/util/Properties",	_JC_JLONG(0x884c3edb343dfb63) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_security_auth_login_Configuration__241$vtype _jc_javax_security_auth_login_Configuration__241$type = {
    .type= {
	.name=			"javax/security/auth/login/Configuration$1",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_javax_security_auth_login_Configuration__241$interfaces) / sizeof(*_jc_javax_security_auth_login_Configuration__241$interfaces),
	.interfaces=		_jc_javax_security_auth_login_Configuration__241$interfaces,
	.imethod_hash_table=	_jc_javax_security_auth_login_Configuration__241$imethod_hash_table,
	.imethod_quick_table=	_jc_javax_security_auth_login_Configuration__241$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x8290523a8a34bfb5),
		.source_file=		"Configuration.java",
		.instance_size=		sizeof(_jc_javax_security_auth_login_Configuration__241$refs) + sizeof(_jc_javax_security_auth_login_Configuration__241$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_javax_security_auth_login_Configuration__241$methods) / sizeof(*_jc_javax_security_auth_login_Configuration__241$methods),
		.methods=		_jc_javax_security_auth_login_Configuration__241$methods,
		.instanceof_hash_table=	_jc_javax_security_auth_login_Configuration__241$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_javax_security_auth_login_Configuration__241$class_depends) / sizeof(*_jc_javax_security_auth_login_Configuration__241$class_depends),
		.class_depends=		_jc_javax_security_auth_login_Configuration__241$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_security_auth_login_Configuration__241= {
	    .run$b190d7b16d5785b8=
		&_jc_javax_security_auth_login_Configuration__241$method$run$b190d7b16d5785b8,
	},
    }
};

==> jc-1.4.5.tar.gz: javax/security/auth/login/Configuration__241.c <==
// final class javax.security.auth.login.Configuration$1

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d38282f3d5f80887 java_lang_SecurityManager
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 94d357637b968dda java_lang_StringBuffer
// @dep_class 53cc8e2333795f04 java_lang_System
// @dep_class fe58a8cfe9b5b994 java_security_PrivilegedAction
// @dep_class 89bf77984bd9669e java_security_Security
// @dep_class 884c3edb343dfb63 java_util_Properties
// @dep_class 8290523a8a34bfb5 javax_security_auth_login_Configuration__241

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_SecurityManager
// @dep_header java_lang_String
// @dep_header java_lang_StringBuffer
// @dep_header java_lang_System
// @dep_header java_security_PrivilegedAction
// @dep_header java_security_Security
// @dep_header java_util_Properties
// @dep_header javax_security_auth_login_Configuration__241

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/SecurityManager.h"
#include "java/lang/String.h"
#include "java/lang/StringBuffer.h"
#include "java/lang/System.h"
#include "java/security/PrivilegedAction.h"
#include "java/security/Security.h"
#include "java/util/Properties.h"
#include "javax/security/auth/login/Configuration__241.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_javax_security_auth_login_Configuration__241$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_javax_security_auth_login_Configuration__241$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_security_auth_login_Configuration__241$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_javax_security_auth_login_Configuration__241$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_security_auth_login_Configuration__241$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_javax_security_auth_login_Configuration__241$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_security_auth_login_Configuration__241$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_security_auth_login_Configuration__241, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_javax_security_auth_login_Configuration__241$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_javax_security_auth_login_Configuration__241$object *this)
{
	struct _jc_javax_security_auth_login_Configuration__241$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(74);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public final java.lang.Object run()
//

static _jc_linenum _jc_javax_security_auth_login_Configuration__241$linenum_table$run$b190d7b16d5785b8[];

static const unsigned char _jc_javax_security_auth_login_Configuration__241$param_ptypes$run$b190d7b16d5785b8[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_security_auth_login_Configuration__241$method_info$run$b190d7b16d5785b8 = {
	.name=			"run",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_javax_security_auth_login_Configuration__241$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_javax_security_auth_login_Configuration__241$param_ptypes$run$b190d7b16d5785b8,
	.signature_hash=	_JC_JLONG(0xb190d7b16d5785b8),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_javax_security_auth_login_Configuration__241$method$run$b190d7b16d5785b8,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_security_auth_login_Configuration__241$vtable, javax_security_auth_login_Configuration__241.run$b190d7b16d5785b8) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_security_auth_login_Configuration__241$linenum_table$run$b190d7b16d5785b8
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_security_auth_login_Configuration__241, run$b190d7b16d5785b8);

_jc_java_lang_Object$object * _JC_JCNI_ATTR
_jc_javax_security_auth_login_Configuration__241$method$run$b190d7b16d5785b8(_jc_env *const env, _jc_javax_security_auth_login_Configuration__241$object *this)
{
	jint i0;
	struct _jc_javax_security_auth_login_Configuration__241$object *r0;
	struct _jc_java_lang_String$object *r1;
	struct _jc_java_lang_StringBuffer$object *r2;
	struct _jc_java_lang_String$object *r3;
	struct _jc_java_util_Properties$object *r4;
	struct _jc_java_lang_SecurityManager$object *r5;
	struct _jc_java_lang_String$object *r6;
	struct _jc_java_lang_String$object *r7;
	_jc_char_array *r8;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_ACTIVE_USE(env, java_security_Security);
	_JC_LINE_NUMBER(77);				// 0
	r1 = _JC_STRING(env, "login.configuration.provider");
	_JC_ACTIVE_USE(env, java_lang_System);
	r5 = _JC_STATIC_FIELD(env, java_lang_SecurityManager, current, 0);
	if (r5 == _JC_NULL)
		goto label0;
	r2 = _JC_NEW(env, java_lang_StringBuffer);
	r7 = _JC_STRING(env, "getProperty.");
	i0 = _JC_PRIM_FIELD(env, r7, java_lang_String, count);
	_JC_PRIM_FIELD(env, r2, java_lang_StringBuffer, count) = i0;
	i0 = _JC_PRIM_FIELD(env, r2, java_lang_StringBuffer, count);
	i0 = i0 + 16;
	r8 = _JC_NEW_PRIM_ARRAY(env, char, 1, i0);
	_JC_REF_FIELD(env, r2, java_lang_StringBuffer, value) = r8;
	i0 = _JC_PRIM_FIELD(env, r2, java_lang_StringBuffer, count);
	r8 = _JC_REF_FIELD(env, r2, java_lang_StringBuffer, value);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_String, getChars$c684dea7317ff063, 0, r7, 0, i0, r8, 0);
	r2 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r2, r1);
	r6 = _JC_NEW(env, java_lang_String);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_String, _init$aa54f0755ac8f3ce, 0, r6, r2);
	_JC_INVOKE_VIRTUAL(env, java_lang_SecurityManager, checkSecurityAccess$3e1898ffed69827d, r5, r6);

label0:
	r4 = _JC_STATIC_FIELD(env, java_security_Security, secprops, 1);
	r3 = _JC_INVOKE_VIRTUAL(env, java_util_Properties, getProperty$17fb18205ea95f87, r4, r1);
	return r3;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_security_auth_login_Configuration__241$methods[] = {
	&_jc_javax_security_auth_login_Configuration__241$method_info$_init$52f4ad9f2989aeee,
	&_jc_javax_security_auth_login_Configuration__241$method_info$run$b190d7b16d5785b8
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_javax_security_auth_login_Configuration__241$interfaces[] = {
	&_jc_java_security_PrivilegedAction$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_javax_security_auth_login_Configuration__241$imethod_hash_bucket_56[] = {
	&_jc_javax_security_auth_login_Configuration__241$method_info$run$b190d7b16d5785b8,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_javax_security_auth_login_Configuration__241$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[56]=	_jc_javax_security_auth_login_Configuration__241$imethod_hash_bucket_56
};

// Interface "quick" lookup hash table
static const void *_jc_javax_security_auth_login_Configuration__241$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[56]=	&_jc_javax_security_auth_login_Configuration__241$method$run$b190d7b16d5785b8
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_security_auth_login_Configuration__241$instanceof_hash_bucket_20[] = {
	&_jc_java_security_PrivilegedAction$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_security_auth_login_Configuration__241$instanceof_hash_bucket_53[] = {
	&_jc_javax_security_auth_login_Configuration__241$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_security_auth_login_Configuration__241$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_security_auth_login_Configuration__241$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[20]=	_jc_javax_security_auth_login_Configuration__241$instanceof_hash_bucket_20,
	[53]=	_jc_javax_security_auth_login_Configuration__241$instanceof_hash_bucket_53,
	[101]=	_jc_javax_security_auth_login_Configuration__241$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_security_auth_login_Configuration__241$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/SecurityManager",	_JC_JLONG(0xd38282f3d5f80887) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/StringBuffer",	_JC_JLONG(0x94d357637b968dda) },
	{ "java/lang/System",	_JC_JLONG(0x53cc8e2333795f04) },
	{ "java/security/PrivilegedAction",	_JC_JLONG(0xfe58a8cfe9b5b994) },
	{ "java/security/Security",	_JC_JLONG(0x89bf77984bd9669e) },
	{ "java/util/Properties",	_JC_JLONG(0x884c3edb343dfb63) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_security_auth_login_Configuration__241$vtype _jc_javax_security_auth_login_Configuration__241$type = {
    .type= {
	.name=			"javax/security/auth/login/Configuration$1",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_javax_security_auth_login_Configuration__241$interfaces) / sizeof(*_jc_javax_security_auth_login_Configuration__241$interfaces),
	.interfaces=		_jc_javax_security_auth_login_Configuration__241$interfaces,
	.imethod_hash_table=	_jc_javax_security_auth_login_Configuration__241$imethod_hash_table,
	.imethod_quick_table=	_jc_javax_security_auth_login_Configuration__241$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x8290523a8a34bfb5),
		.source_file=		"Configuration.java",
		.instance_size=		sizeof(_jc_javax_security_auth_login_Configuration__241$refs) + sizeof(_jc_javax_security_auth_login_Configuration__241$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_javax_security_auth_login_Configuration__241$methods) / sizeof(*_jc_javax_security_auth_login_Configuration__241$methods),
		.methods=		_jc_javax_security_auth_login_Configuration__241$methods,
		.instanceof_hash_table=	_jc_javax_security_auth_login_Configuration__241$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_javax_security_auth_login_Configuration__241$class_depends) / sizeof(*_jc_javax_security_auth_login_Configuration__241$class_depends),
		.class_depends=		_jc_javax_security_auth_login_Configuration__241$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_security_auth_login_Configuration__241= {
	    .run$b190d7b16d5785b8=
		&_jc_javax_security_auth_login_Configuration__241$method$run$b190d7b16d5785b8,
	},
    }
};
